@@ -17,7 +17,7 @@ open Proofview.Notations
 
 type tactic = unit Proofview.tactic
 
-let mkArrow x y = mkArrow x Sorts.Relevant y
+let mkArrow x y = mkArrow x ERelevance.relevant y
 (* The kernel will fix the relevance if needed. Also as an equality
    tactic we probably are only called on relevant terms. *)
 
@@ -40,30 +40,17 @@ let get_fresh r = new_monomorphic_global (Lazy.force r)
 let get_efresh r = EConstr.of_constr (new_monomorphic_global (Lazy.force r))
                         
 
-(* A clause specifying that the [let] should not try to fold anything
-   in the goal *)
-let nowhere =
-  { Locus.onhyps = Some [];
-    Locus.concl_occs = Locus.NoOccurrences
-  }
-
-let retype c =
-  Proofview.Goal.enter begin fun gl ->
-  let sigma, _ = Typing.type_of (Proofview.Goal.env gl) (Proofview.Goal.sigma gl) c in
-  Proofview.Unsafe.tclEVARS sigma
-  end
-
-(* similar to retype above. No Idea when/why this is needed, I smell some ugly hack.
-  Apparently, it has to do with the need to recompute universe constrains if we just compose terms *)
-let tclRETYPE c=
+(* Typically needed to recompute universe constraints,
+   eg if we do [mkApp (id, [|some_ty; some_v|])]
+   (universe of some_ty must be <= universe of id argument) *)
+let tclRETYPE c =
   let open Proofview in
-  tclEVARMAP >>= fun sigma ->
-  Proofview.Goal.enter (fun goal ->
-      let env = Proofview.Goal.env goal in
+  Goal.enter_one ~__LOC__ (fun goal ->
+      let env = Goal.env goal in
+      let sigma = Goal.sigma goal in
       let sigma,_ = Typing.type_of env sigma c in
-      Unsafe.tclEVARS sigma
-    )
-  
+      Unsafe.tclEVARS sigma)
+
 (** {1 Tacticals}  *)
 
 let tclTIME msg tac =
@@ -94,18 +81,6 @@ let show_proof pstate : unit =
   ()
 
 
-let cps_mk_letin
-    (name:string)
-    (c: constr)
-    (k : constr -> tactic)
-: tactic =
-  Proofview.Goal.enter begin fun goal ->
-    let name = (Id.of_string name) in
-    let name =  Tactics.fresh_id_in_env Id.Set.empty name (Tacmach.pf_env goal) in
-    let letin = Tactics.letin_tac None (Name name) c None nowhere in
-    Tacticals.tclTHENLIST [retype c; letin; (k (mkVar name))]
-  end
-
 let mk_letin (name:string) (c: constr) : constr Proofview.tactic =
   let open Proofview in
   let name = (Id.of_string name) in
